@@ -25,18 +25,18 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 
-#include <KIconLoader>
 #include <KLocale>
 #include <KDebug>
 #include <KFadeWidgetEffect>
 
+#include <KoIcon.h>
 #include <widget/properties/KexiPropertyEditorView.h>
 #include <widget/KexiObjectInfoLabel.h>
 #include <widget/KexiDataSourceComboBox.h>
 #include <widget/fields/KexiFieldListView.h>
 #include <widget/fields/KexiFieldComboBox.h>
 #include <kexiutils/SmallToolButton.h>
-#include <kexidb/connection.h>
+#include <db/connection.h>
 #include <kexiproject.h>
 
 #include <formeditor/commands.h>
@@ -98,7 +98,7 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
 
 #if 0 //2.0: clear button is available in the combobox itself
     m_clearWidgetDSButton = new KexiSmallToolButton(
-        KIcon("edit-clear-locationbar-rtl"), QString(), this);
+        koIcon("edit-clear-locationbar-rtl"), QString(), this);
     m_clearWidgetDSButton->setObjectName("clearWidgetDSButton");
     m_clearWidgetDSButton->setMinimumHeight(m_widgetDSLabel->minimumHeight());
     m_clearWidgetDSButton->setToolTip(i18n("Clear widget's data source"));
@@ -139,7 +139,7 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
 //m_dataSourceLabel->setPaletteBackgroundColor(Qt::red);
 
     m_gotoButton = new KexiSmallToolButton(
-        KIcon("go-jump"), QString(), this);
+        koIcon("go-jump"), QString(), this);
     m_gotoButton->setObjectName("gotoButton");
 //2.0    m_gotoButton->setMinimumHeight(m_dataSourceLabel->minimumHeight());
     m_gotoButton->setToolTip(i18n("Go to selected form's data source"));
@@ -149,7 +149,7 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
 
 #if 0 //2.0: clear button is available in the combobox itself
     m_clearDSButton = new KexiSmallToolButton(
-        KIcon("edit-clear-locationbar-rtl"), QString(), this);
+        koIcon("edit-clear-locationbar-rtl"), QString(), this);
     m_clearDSButton->setObjectName("clearDSButton");
     m_clearDSButton->setMinimumHeight(m_dataSourceLabel->minimumHeight());
     m_clearDSButton->setToolTip(i18n("Clear form's data source"));
@@ -199,7 +199,7 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
     mainLayout()->addLayout(hlyr);
     m_mousePointerLabel = new QLabel(this);
     hlyr->addWidget(m_mousePointerLabel);
-    m_mousePointerLabel->setPixmap(SmallIcon("mouse_pointer"));
+    m_mousePointerLabel->setPixmap(koIcon("mouse_pointer"));
     m_mousePointerLabel->setFixedWidth(m_mousePointerLabel->pixmap()
                                        ? m_mousePointerLabel->pixmap()->width() : 0);
     m_availableFieldsDescriptionLabel = new QLabel(
@@ -221,7 +221,7 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
     hlyr->addWidget(m_availableFieldsLabel);
 
     m_addField = new KexiSmallToolButton(
-        KIcon("add_field"), i18nc("Insert selected field into form", "Insert"), this);
+        koIcon("add_field"), i18nc("Insert selected field into form", "Insert"), this);
     m_addField->setObjectName("addFieldButton");
 //2.0    m_addField->setMinimumHeight(m_availableFieldsLabel->minimumHeight());
 // m_addField->setTextPosition(QToolButton::Right);
@@ -259,6 +259,9 @@ KexiDataSourcePage::KexiDataSourcePage(QWidget *parent)
 
 KexiDataSourcePage::~KexiDataSourcePage()
 {
+#ifdef KEXI_NO_AUTOFIELD_WIDGET
+    delete m_tableOrQuerySchema;
+#endif
 }
 
 void KexiDataSourcePage::setProject(KexiProject *prj)
