@@ -20,7 +20,7 @@
 
 #include "kexidbtextedit.h"
 #include "kexidblineedit.h"
-#include <kexidb/queryschema.h>
+#include <db/queryschema.h>
 #include <kexiutils/utils.h>
 
 #include <kapplication.h>
@@ -85,7 +85,6 @@ KexiDBTextEdit::KexiDBTextEdit(QWidget *parent)
 //hmm disabled again because this makes the widget disappear entirely
 //    setAutoFillBackground(true); // otherwise we get transparent background...
 //    installEventFilter(this);
-    setBackgroundRole(QPalette::Base);
 }
 
 KexiDBTextEdit::~KexiDBTextEdit()
@@ -106,28 +105,19 @@ void KexiDBTextEdit::setValueInternal(const QVariant& add, bool removeOld)
 //! @todo how about rich text?
     if (m_columnInfo && m_columnInfo->field->type() == KexiDB::Field::Boolean) {
 //! @todo temporary solution for booleans!
-        KTextEdit::setHtml(add.toBool() ? "1" : "0");
+        KTextEdit::setPlainText(add.toBool() ? "1" : "0");
     } else {
-        QString t;
-        if (removeOld) {
-            t = add.toString();
-        }
-        else {
-            t = m_origValue.toString() + add.toString();
-        }
-
-        if (acceptRichText()) {
-            KTextEdit::setHtml(t);
-        }
-        else {
-            KTextEdit::setPlainText(t);
-        }
+        if (removeOld)
+            KTextEdit::setPlainText(add.toString());
+        else
+            KTextEdit::setPlainText(m_origValue.toString() + add.toString());
     }
 }
 
 QVariant KexiDBTextEdit::value()
 {
-    return acceptRichText() ? toHtml() : toPlainText();
+//! @todo how about rich text?
+    return toPlainText();
 }
 
 void KexiDBTextEdit::slotTextChanged()
@@ -136,22 +126,8 @@ void KexiDBTextEdit::slotTextChanged()
         return;
 
     if (m_length > 0) {
-        QString t;
-        if (acceptRichText()) {
-            t = toHtml();
-        }
-        else {
-            t = toPlainText();
-        }
-        if (t.length() > (int)m_length) {
-            m_slotTextChanged_enabled = false;
-            if (acceptRichText()) {
-#warning todo setHtml(t.left(m_length));
-            }
-            else {
-                setPlainText(t.left(m_length));
-            }
-            m_slotTextChanged_enabled = true;
+        if (toPlainText().length() > (int)m_length) {
+            setPlainText(toPlainText().left(m_length));
             moveCursorToEnd();
         }
     }
@@ -161,12 +137,12 @@ void KexiDBTextEdit::slotTextChanged()
 
 bool KexiDBTextEdit::valueIsNull()
 {
-    return (acceptRichText() ? toHtml() : toPlainText()).isNull();
+    return toPlainText().isNull();
 }
 
 bool KexiDBTextEdit::valueIsEmpty()
 {
-    return (acceptRichText() ? toHtml() : toPlainText()).isEmpty();
+    return toPlainText().isEmpty();
 }
 
 bool KexiDBTextEdit::isReadOnly() const
@@ -227,7 +203,7 @@ void KexiDBTextEdit::setColumnInfo(KexiDB::QueryColumnInfo* cinfo)
         return;
     }
 
-    if (cinfo->field->type() == KexiDB::Field::Text) {
+    if (cinfo->field->isTextType()) {
         if (!designMode()) {
             if (cinfo->field->maxLength() > 0) {
                 m_length = cinfo->field->maxLength();
@@ -242,7 +218,6 @@ void KexiDBTextEdit::paintEvent(QPaintEvent *pe)
 {
     KTextEdit::paintEvent(pe);
     QPainter p(viewport());
-    //! @todo how about rich text?
     KexiDBTextWidgetInterface::paint(this, &p, toPlainText().isEmpty(), alignment(), hasFocus());
 }
 
