@@ -26,6 +26,7 @@
 #include <QLabel>
 #include <QSplitter>
 #include <QByteArray>
+#include <QHash>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -415,8 +416,8 @@ KexiTableDesignerView::createPropertySet(int row, const KexiDB::Field& field, bo
     prop->setOption("minValueText", i18nc("Auto Decimal Places", "Auto"));
 
 //! @todo set reasonable default for column width
-    set->addProperty(prop = new KoProperty::Property("width", QVariant(0) /*field.width()*//*200?*/,
-                                                     i18n("Column Width")));
+    set->addProperty(prop = new KoProperty::Property("defaultWidth", QVariant(0) /*field.width()*//*200?*/,
+                                                     i18n("Default Width")));
 #ifdef KEXI_NO_UNFINISHED
     prop->setVisible(false);
 #endif
@@ -1183,11 +1184,11 @@ KexiDB::Field * KexiTableDesignerView::buildField(const KoProperty::Set &set) co
 {
     //create a map of property values
     kDebug() << set["type"].value();
-    QHash<QByteArray, QVariant> values(KoProperty::propertyValues(set));
+    QMap<QByteArray, QVariant> values(KoProperty::propertyValues(set));
     //remove internal values, to avoid creating custom field's properties
     KexiDB::Field *field = new KexiDB::Field();
 
-    for (QMutableHashIterator<QByteArray, QVariant> it(values); it.hasNext();) {
+    for (QMutableMapIterator<QByteArray, QVariant> it(values); it.hasNext();) {
         it.next();
         const QByteArray propName(it.key());
         if (d->internalPropertyNames.contains(propName)
@@ -1397,7 +1398,9 @@ tristate KexiTableDesignerView::buildAlterTableActions(
     return true;
 }
 
-KexiDB::SchemaData* KexiTableDesignerView::storeNewData(const KexiDB::SchemaData& sdata, bool &cancel)
+KexiDB::SchemaData* KexiTableDesignerView::storeNewData(const KexiDB::SchemaData& sdata,
+                                                        KexiView::StoreNewDataOptions options,
+                                                        bool &cancel)
 {
     if (tempData()->table || window()->schemaData()) //must not be
         return 0;
@@ -1415,9 +1418,13 @@ KexiDB::SchemaData* KexiTableDesignerView::storeNewData(const KexiDB::SchemaData
     if (res == true) {
         //todo
         KexiDB::Connection *conn = KexiMainWindowIface::global()->project()->dbConnection();
-        res = conn->createTable(tempData()->table);
-        if (res != true)
+        res = conn->createTable(tempData()->table, options & KexiView::OverwriteExistingObject);
+        if (res == true) {
+            res = KexiMainWindowIface::global()->project()->removeUserDataBlock(tempData()->table->id());
+        }
+        else {
             window()->setStatus(conn, "");
+        }
     }
 
     if (res == true) {
@@ -1905,7 +1912,7 @@ void KexiTableDesignerView::changePropertyVisibility(
 void KexiTableDesignerView::propertySetSwitched()
 {
     KexiDataTable::propertySetSwitched();
-    KexiLookupColumnPage *page = static_cast<KexiTablePart*>(window()->part())->lookupColumnPage();
+    KexiLookupColumnPage *page = qobject_cast<KexiTablePart*>(window()->part())->lookupColumnPage();
     if (page)
         page->assignPropertySet(propertySet());
 }
