@@ -34,12 +34,14 @@
 
 #include <kmessagebox.h>
 
+#include <KoIcon.h>
+
 #include <kexi.h>
 #include <kexi_global.h>
 #include <kexiutils/validator.h>
 #include <widget/utils/kexirecordnavigator.h>
 #include <widget/utils/kexirecordmarker.h>
-#include <kexidb/roweditbuffer.h>
+#include <db/roweditbuffer.h>
 
 //#include "kexitableviewheader.h"
 
@@ -141,11 +143,11 @@ void KexiDataAwareObjectInterface::setData(KexiTableViewData *data, bool owner)
     clearColumnsInternal(false);
     if (m_data) {
         int i = -1;
-        foreach(KexiTableViewColumn *col, m_data->columns()) {
+        foreach(KexiTableViewColumn *col, *m_data->columns()) {
             i++;
             KexiDB::Field *f = col->field();
             if (col->isVisible()) {
-                int wid = f->width();
+                int wid = col->width();
                 if (wid == 0)
                     wid = KEXI_DEFAULT_DATA_COLUMN_WIDTH;//default col width in pixels
 //! @todo add col width configuration and storage
@@ -203,7 +205,7 @@ void KexiDataAwareObjectInterface::setData(KexiTableViewData *data, bool owner)
         if (!m_insertItem) {//first setData() call - add 'insert' item
             m_insertItem = m_data->createItem();
         } else {//just reinit
-            m_insertItem->init(m_data->columns().count());
+            m_insertItem->init(m_data->columnsCount());
         }
     }
 
@@ -1231,7 +1233,7 @@ void KexiDataAwareObjectInterface::deleteCurrentRow()
         if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(
                     dynamic_cast<QWidget*>(this),
                     i18n("Do you want to delete selected record?"), QString(),
-                    KGuiItem(i18n("&Delete Record"), "edit-delete"), KStandardGuiItem::cancel(),
+                    KGuiItem(i18n("&Delete Record"), koIconName("edit-delete")), KStandardGuiItem::cancel(),
                     "dontAskBeforeDeleteRow"/*config entry*/,
                     KMessageBox::Notify | KMessageBox::Dangerous))
         {
@@ -1475,7 +1477,7 @@ int KexiDataAwareObjectInterface::dataColumns() const
 {
     if (!hasData())
         return 0;
-    return m_data->columns().count();
+    return m_data->columnsCount();
 }
 
 QVariant KexiDataAwareObjectInterface::columnDefaultValue(int /*col*/) const
