@@ -44,7 +44,7 @@
 
 #include <widget/dataviewcommon/kexitableviewdata.h>
 #include "kexitableedit.h"
-#include <kexiutils/tristate.h>
+#include <db/tristate.h>
 #include <widget/utils/kexirecordnavigator.h>
 #include <widget/utils/kexisharedactionclient.h>
 #include <widget/dataviewcommon/kexidataawareobjectiface.h>
