@@ -112,7 +112,7 @@ public:
 
     }
 
-    QImage createThumbnail(qint32 w, qint32 h) {
+    QImage createThumbnail(qint32 w, qint32 h, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags) {
         QImage thumbnail;
 
         if(m_data->m_thumbnailsValid) {
@@ -124,7 +124,7 @@ public:
         }
 
         if(thumbnail.isNull()) {
-            thumbnail = m_paintDevice->createThumbnail(w, h, 0, QRect());
+            thumbnail = m_paintDevice->createThumbnail(w, h, QRect(), renderingIntent, conversionFlags);
             cacheThumbnail(w, h, thumbnail);
         }
 
@@ -168,7 +168,7 @@ public:
     PaintDeviceCache cache;
     qint32 x;
     qint32 y;
-    KoColorSpace* colorSpace;
+    const KoColorSpace* colorSpace;
 
 };
 
@@ -209,7 +209,7 @@ void KisPaintDevice::init(KisDataManagerSP explicitDataManager,
         defaultBounds = new KisDefaultBounds();
     }
 
-    m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(colorSpace);
+    m_d->colorSpace = colorSpace;
     Q_ASSERT(m_d->colorSpace);
 
     if(explicitDataManager) {
@@ -238,7 +238,7 @@ KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs)
     , m_d(new Private(this))
 {
     if (this != &rhs) {
-        m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(rhs.m_d->colorSpace);
+        m_d->colorSpace = rhs.m_d->colorSpace;
         Q_ASSERT(m_d->colorSpace);
 
         m_d->x = rhs.m_d->x;
@@ -256,7 +256,6 @@ KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs)
 
 KisPaintDevice::~KisPaintDevice()
 {
-    KoColorSpaceRegistry::instance()->releaseColorSpace(m_d->colorSpace);
     delete m_d;
 }
 
@@ -276,8 +275,7 @@ void KisPaintDevice::prepareClone(KisPaintDeviceSP src)
             setDefaultPixel(src->defaultPixel());
         }
 
-        KoColorSpaceRegistry::instance()->releaseColorSpace(m_d->colorSpace);
-        m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(src->colorSpace());
+        m_d->colorSpace = src->colorSpace();
     }
     setDefaultBounds(src->defaultBounds());
     setParentNode(0);
@@ -559,10 +557,10 @@ bool KisPaintDevice::read(KoStore *store)
     return retval;
 }
 
-KUndo2Command* KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
+KUndo2Command* KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags)
 {
     m_d->cache.invalidate();
-    dbgImage << this << colorSpace()->id() << dstColorSpace->id() << renderingIntent;
+    dbgImage << this << colorSpace()->id() << dstColorSpace->id() << renderingIntent << conversionFlags;
     if (*colorSpace() == *dstColorSpace) {
         return 0;
     }
@@ -598,7 +596,7 @@ KUndo2Command* KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoC
             const quint8 *srcData = srcIt->oldRawData();
             quint8 *dstData = dstIt->rawData();
 
-            m_d->colorSpace->convertPixelsTo(srcData, dstData, dstColorSpace, columns, renderingIntent);
+            m_d->colorSpace->convertPixelsTo(srcData, dstData, dstColorSpace, columns, renderingIntent, conversionFlags);
 
             column += columns;
             columnsRemaining -= columns;
@@ -607,7 +605,7 @@ KUndo2Command* KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoC
     }
 
     KisDataManagerSP oldData = m_datamanager;
-    KoColorSpace *oldColorSpace = m_d->colorSpace;
+    const KoColorSpace *oldColorSpace = m_d->colorSpace;
 
     KisPaintDeviceConvertTypeCommand* cmd = new KisPaintDeviceConvertTypeCommand(this,
                                                                                  oldData,
@@ -627,8 +625,7 @@ void KisPaintDevice::setProfile(const KoColorProfile * profile)
     const KoColorSpace * dstSpace =
             KoColorSpaceRegistry::instance()->colorSpace(colorSpace()->colorModelId().id(), colorSpace()->colorDepthId().id(), profile);
     if (dstSpace) {
-        KoColorSpaceRegistry::instance()->releaseColorSpace(m_d->colorSpace);
-        m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(dstSpace);
+        m_d->colorSpace = dstSpace;
     }
     emit profileChanged(profile);
 }
@@ -639,8 +636,7 @@ void KisPaintDevice::setDataManager(KisDataManagerSP data, const KoColorSpace *
     m_d->cache.setupCache();
 
     if(colorSpace) {
-        KoColorSpaceRegistry::instance()->releaseColorSpace(m_d->colorSpace);
-        m_d->colorSpace = KoColorSpaceRegistry::instance()->grabColorSpace(colorSpace);
+        m_d->colorSpace = colorSpace;
         emit colorSpaceChanged(colorSpace);
     }
 }
@@ -660,7 +656,7 @@ void KisPaintDevice::convertFromQImage(const QImage& _image, const KoColorProfil
         quint8 * dstData = new quint8[image.width() * image.height() * pixelSize()];
         KoColorSpaceRegistry::instance()
                 ->colorSpace(RGBAColorModelID.id(), Integer8BitsColorDepthID.id(), profile)
-                ->convertPixelsTo(image.bits(), dstData, colorSpace(), image.width() * image.height());
+                ->convertPixelsTo(image.bits(), dstData, colorSpace(), image.width() * image.height(), KoColorConversionTransformation::IntentPerceptual, KoColorConversionTransformation::BlackpointCompensation);
 
         writeBytes(dstData, offsetX, offsetY, image.width(), image.height());
         delete[] dstData;
@@ -668,7 +664,7 @@ void KisPaintDevice::convertFromQImage(const QImage& _image, const KoColorProfil
     m_d->cache.invalidate();
 }
 
-QImage KisPaintDevice::convertToQImage(const KoColorProfile *dstProfile) const
+QImage KisPaintDevice::convertToQImage(const KoColorProfile *dstProfile, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags) const
 {
     qint32 x1;
     qint32 y1;
@@ -684,10 +680,10 @@ QImage KisPaintDevice::convertToQImage(const KoColorProfile *dstProfile) const
     w = rc.width();
     h = rc.height();
 
-    return convertToQImage(dstProfile, x1, y1, w, h);
+    return convertToQImage(dstProfile, x1, y1, w, h, renderingIntent, conversionFlags);
 }
 
-QImage KisPaintDevice::convertToQImage(const KoColorProfile *  dstProfile, qint32 x1, qint32 y1, qint32 w, qint32 h) const
+QImage KisPaintDevice::convertToQImage(const KoColorProfile *  dstProfile, qint32 x1, qint32 y1, qint32 w, qint32 h, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags) const
 {
 
     if (w < 0)
@@ -709,14 +705,13 @@ QImage KisPaintDevice::convertToQImage(const KoColorProfile *  dstProfile, qint3
     // XXX: Is this really faster than converting line by line and building the QImage directly?
     //      This copies potentially a lot of data.
     readBytes(data, x1, y1, w, h);
-    QImage image = colorSpace()->convertToQImage(data, w, h, dstProfile,
-                                                 KoColorConversionTransformation::IntentPerceptual);
+    QImage image = colorSpace()->convertToQImage(data, w, h, dstProfile, renderingIntent, conversionFlags);
     delete[] data;
 
     return image;
 }
 
-KisPaintDeviceSP KisPaintDevice::createThumbnailDevice(qint32 w, qint32 h, const KisSelection * selection, QRect rect) const
+KisPaintDeviceSP KisPaintDevice::createThumbnailDevice(qint32 w, qint32 h, QRect rect) const
 {
     KisPaintDeviceSP thumbnail = new KisPaintDevice(colorSpace());
 
@@ -762,16 +757,16 @@ KisPaintDeviceSP KisPaintDevice::createThumbnailDevice(qint32 w, qint32 h, const
 
 }
 
-QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h, const KisSelection *selection, QRect rect)
+QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h, QRect rect, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags)
 {
-    KisPaintDeviceSP dev = createThumbnailDevice(w, h, selection, rect);
-    QImage thumbnail = dev->convertToQImage(KoColorSpaceRegistry::instance()->rgb8()->profile());
+    KisPaintDeviceSP dev = createThumbnailDevice(w, h, rect);
+    QImage thumbnail = dev->convertToQImage(KoColorSpaceRegistry::instance()->rgb8()->profile(), renderingIntent, conversionFlags);
     return thumbnail;
 }
 
-QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h)
+QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags)
 {
-    return m_d->cache.createThumbnail(w, h);
+    return m_d->cache.createThumbnail(w, h, renderingIntent, conversionFlags);
 }
 
 KisHLineIteratorSP KisPaintDevice::createHLineIteratorNG(qint32 x, qint32 y, qint32 w)
@@ -1054,13 +1049,7 @@ quint32 KisPaintDevice::channelCount() const
     return _channelCount;
 }
 
-KoColorSpace * KisPaintDevice::colorSpace()
-{
-    Q_ASSERT(m_d->colorSpace != 0);
-    return m_d->colorSpace;
-}
-
-const KoColorSpace * KisPaintDevice::colorSpace() const
+const KoColorSpace *KisPaintDevice::colorSpace() const
 {
     Q_ASSERT(m_d->colorSpace != 0);
     return m_d->colorSpace;
