@@ -2487,6 +2487,17 @@ void KisPainter::renderMirrorMaskSafe(QRect rc, KisFixedPaintDeviceSP dab, bool
     renderMirrorMask(rc, dabToProcess);
 }
 
+void KisPainter::renderMirrorMaskSafe(QRect rc, KisPaintDeviceSP dab, int sx, int sy, KisFixedPaintDeviceSP mask, bool preserveMask)
+{
+    if (!d->mirrorHorizontaly && !d->mirrorVerticaly) return;
+
+    KisFixedPaintDeviceSP maskToProcess = mask;
+    if (preserveMask) {
+        maskToProcess = new KisFixedPaintDevice(*mask);
+    }
+    renderMirrorMask(rc, dab, sx, sy, maskToProcess);
+}
+
 void KisPainter::renderMirrorMask(QRect rc, KisFixedPaintDeviceSP dab)
 {
     int x = rc.topLeft().x();
@@ -2596,17 +2607,6 @@ void KisPainter::renderMirrorMask(QRect rc, KisPaintDeviceSP dab){
     }
 }
 
-void KisPainter::renderMirrorMask(QRect rc, KisPaintDeviceSP dab, KisFixedPaintDeviceSP mask){
-    if (d->mirrorHorizontaly || d->mirrorVerticaly){
-        KisFixedPaintDeviceSP mirrorDab = new KisFixedPaintDevice(device()->colorSpace());
-        QRect dabRc( QPoint(0,0), QSize(rc.width(),rc.height()) );
-        mirrorDab->setRect(dabRc);
-        mirrorDab->initialize();
-        dab->readBytes(mirrorDab->data(),rc);
-        renderMirrorMask(rc, mirrorDab, mask);
-    }
-}
-
 void KisPainter::renderMirrorMask(QRect rc, KisPaintDeviceSP dab, int sx, int sy, KisFixedPaintDeviceSP mask)
 {
     if (d->mirrorHorizontaly || d->mirrorVerticaly){
