@@ -522,7 +522,7 @@ bool PSDLayerRecord::readChannels(QIODevice *io, KisPaintDeviceSP device)
     return false;
 }
 
-bool PSDLayerRecord::doGrayscale(KisPaintDeviceSP dev, QIODevice *io)
+bool PSDLayerRecord::doGrayscale(KisPaintDeviceSP /*dev*/, QIODevice */*io*/)
 {
     return false;
 }
@@ -531,7 +531,7 @@ bool PSDLayerRecord::doRGB(KisPaintDeviceSP dev, QIODevice *io)
 {
     quint64 oldPosition = io->pos();
 
-    int width = right - left;
+    quint64 width = right - left;
     int channelSize = m_header.channelDepth / 8;
     int uncompressedLength = width * channelSize;
 
@@ -637,7 +637,7 @@ bool PSDLayerRecord::doCMYK(KisPaintDeviceSP dev, QIODevice *io)
     qDebug() << "top" << top << "bottom" << bottom << "left" << left << "right" << right;
     quint64 oldPosition = io->pos();
 
-    int width = right - left;
+    quint64 width = right - left;
     int channelSize = m_header.channelDepth / 8;
     int uncompressedLength = width * channelSize;
 
@@ -751,7 +751,7 @@ bool PSDLayerRecord::doCMYK(KisPaintDeviceSP dev, QIODevice *io)
 bool PSDLayerRecord::doLAB(KisPaintDeviceSP dev, QIODevice *io)
 {    quint64 oldPosition = io->pos();
 
-     int width = right - left;
+     quint64 width = right - left;
      int channelSize = m_header.channelDepth / 8;
      int uncompressedLength = width * channelSize;
 
