@@ -23,6 +23,7 @@
 #include <kis_perspective_grid.h>
 #include <kis_tool.h>
 #include <KoToolFactoryBase.h>
+#include <KoIcon.h>
 
 class KisCanvas2;
 
@@ -90,7 +91,7 @@ public:
             : KoToolFactoryBase("KisToolPerspectiveGrid") {
         setToolTip(i18n("Edit the perspective grid"));
         setToolType(TOOL_TYPE_VIEW);
-        setIcon("tool_perspectivegrid");
+        setIconName(koIconNameCStr("tool_perspectivegrid"));
         setPriority(16);
         setActivationShapeId(KRITA_TOOL_ACTIVATION_ID);
     };
