@@ -30,6 +30,7 @@
 #include <kaction.h>
 #include <kactioncollection.h>
 
+#include <KoIcon.h>
 #include <KoPointerEvent.h>
 #include <KoViewConverter.h>
 #include <KoCanvasController.h>
@@ -213,9 +214,18 @@ void KisToolFreehand::mousePressEvent(KoPointerEvent *e)
 
         requestUpdateOutline(e->point);
 
+        if (currentNode() && currentNode()->inherits("KisShapeLayer")) {
+            KisCanvas2 *canvas2 = dynamic_cast<KisCanvas2 *>(canvas());
+            canvas2->view()->showFloatingMessage(i18n("Can't paint on vector layer."), koIcon("draw-brush"));
+        }
+
         if (nodePaintAbility() != PAINT)
             return;
 
+        if (!nodeEditable()) {
+            return;
+        }
+
         setMode(KisTool::PAINT_MODE);
 
         KisCanvas2 *canvas2 = dynamic_cast<KisCanvas2 *>(canvas());
