@@ -40,10 +40,9 @@
 #include <KoPAOdfPageSaveHelper.h>
 #include <KoDrag.h>
 #include <KoPAPastePage.h>
+#include <KoIcon.h>
 
 #include <klocale.h>
-#include <kicon.h>
-#include <kiconloader.h>
 #include <kdebug.h>
 
 #include <QAbstractItemModel>
@@ -312,8 +311,8 @@ KoDocumentSectionModel::PropertyList KoPADocumentModel::properties( KoShape* sha
         l << Property(i18n("Slide"), QString::number(m_document->pageIndex(page) + 1));
     }
 
-    l << Property(i18n("Visible"), SmallIcon("layer-visible-on"), SmallIcon("layer-visible-off"), shape->isVisible());
-    l << Property(i18n("Locked"), SmallIcon("object-locked"), SmallIcon("object-unlocked"), shape->isGeometryProtected());
+    l << Property(i18n("Visible"), koIcon("layer-visible-on"), koIcon("layer-visible-off"), shape->isVisible());
+    l << Property(i18n("Locked"), koIcon("object-locked"), koIcon("object-unlocked"), shape->isGeometryProtected());
     return l;
 }
 
@@ -663,15 +662,15 @@ bool KoPADocumentModel::doDrop(QList<KoPAPageBase *> pages, KoPAPageBase *pageAf
            QString seq = QKeySequence(Qt::ShiftModifier).toString();
            seq.chop(1);
            QAction *popupMoveAction = new QAction(i18n("&Move Here") + '\t' + seq, this);
-           popupMoveAction->setIcon(KIcon("go-jump"));
+           popupMoveAction->setIcon(koIcon("go-jump"));
            seq = QKeySequence(Qt::ControlModifier).toString();
            seq.chop(1);
            QAction *popupCopyAction = new QAction(i18n("&Copy Here") + '\t' + seq, this);
-           popupCopyAction->setIcon(KIcon("edit-copy"));
+           popupCopyAction->setIcon(koIcon("edit-copy"));
            seq = QKeySequence( Qt::ControlModifier + Qt::ShiftModifier ).toString();
            seq.chop(1);
            QAction *popupCancelAction = new QAction(i18n("C&ancel") + '\t' + QKeySequence(Qt::Key_Escape).toString(), this);
-           popupCancelAction->setIcon(KIcon("process-stop"));
+           popupCancelAction->setIcon(koIcon("process-stop"));
 
            if (enableMove) {
                popup.addAction(popupMoveAction);
