@@ -87,6 +87,8 @@
 #include <QDesktopWidget>
 #include <QPrintPreviewDialog>
 
+#include "thememanager.h"
+
 #include "calligraversion.h"
 
 class KoPartManager : public KParts::PartManager
@@ -144,6 +146,7 @@ public:
 #ifdef HAVE_KACTIVITIES
         activityResource = 0;
 #endif
+        themeManager = 0;
     }
     ~KoMainWindowPrivate() {
         qDeleteAll(toolbarList);
@@ -229,6 +232,8 @@ public:
     KActivities::ResourceInstance *activityResource;
 #endif
 
+    Digikam::ThemeManager *themeManager;
+
 };
 
 KoMainWindow::KoMainWindow(const KComponentData &componentData)
@@ -316,6 +321,14 @@ KoMainWindow::KoMainWindow(const KComponentData &componentData)
     d->exportPdf->setEnabled(false);
     d->closeFile->setEnabled(false);
 
+    // populate theme menu
+    d->themeManager = new Digikam::ThemeManager(this);
+    KConfigGroup group(KGlobal::config(), "theme");
+    d->themeManager->setThemeMenuAction(new KActionMenu(i18n("&Themes"), this));
+    d->themeManager->registerThemeActions(actionCollection());
+    d->themeManager->setCurrentTheme(group.readEntry("Theme",
+                                                     d->themeManager->defaultThemeName()));
+
     // set up the action "list" for "Close all Views" (hacky :) (Werner)
     KToggleAction *fullscreenAction  = new KToggleAction(koIcon("view-fullscreen"), i18n("Full Screen Mode"), this);
     actionCollection()->addAction("view_fullscreen", fullscreenAction);
@@ -393,6 +406,13 @@ KoMainWindow::~KoMainWindow()
     cfg.writeEntry("ko_x", frameGeometry().x());
     cfg.writeEntry("ko_y", frameGeometry().y());
 
+    {
+        KConfigGroup group(KGlobal::config(), "theme");
+        group.writeEntry("Theme", d->themeManager->currentThemeName());
+    }
+
+
+
     // Explicitly delete the docker manager to ensure that it is deleted before the dockers
     delete d->dockerManager;
     d->dockerManager = 0;
