@@ -43,6 +43,7 @@
 #include <KoInlineObject.h>
 #include <KoTextInlineRdf.h>
 #include <KoInlineTextObjectManager.h>
+#include <KoTextRangeManager.h>
 #include <KoBookmark.h>
 #include <KoTextMeta.h>
 #include "KoRdfFoaF.h"
@@ -921,13 +922,22 @@ QPair<int, int> KoDocumentRdf::findExtent(KoTextEditor *handler) const
     Q_ASSERT(d->model);
     RDEBUG << "model.sz:" << d->model->statementCount();
 
+    const QTextDocument *document = handler->document();
+
+    // first check for bookmarks
+    KoTextRangeManager *mgr = KoTextDocument(document).textRangeManager();
+    Q_ASSERT(mgr);
+    QHash<int, KoTextRange *> textRanges = mgr->textRangesChangingWithin(0, handler->selectionEnd(), handler->selectionStart(), -1);
+    foreach (const KoTextRange *range, textRanges) {
+        return QPair<int,int>(range->rangeStart(), range->rangeEnd());
+    }
+/*
+    // find the text:meta inline objects
     int startPosition = handler->position();
     KoInlineTextObjectManager *inlineObjectManager
                 = KoTextDocument(handler->document()).inlineTextObjectManager();
     Q_ASSERT(inlineObjectManager);
 
-    // find the bookmark-start or text:meta inline objects
-    const QTextDocument *document = handler->document();
     QTextCursor cursor = document->find(QString(QChar::ObjectReplacementCharacter),
                                         startPosition,
                                         QTextDocument::FindBackward);
@@ -936,19 +946,7 @@ QPair<int, int> KoDocumentRdf::findExtent(KoTextEditor *handler) const
         QTextCharFormat fmt = cursor.charFormat();
         KoInlineObject *obj = inlineObjectManager->inlineTextObject(fmt);
 
-        // first check for bookmarks
-        if (KoBookmark *bookmark = dynamic_cast<KoBookmark*>(obj)) {
-            KoBookmark::BookmarkType type = bookmark->type();
-            if (type == KoBookmark::StartBookmark) {
-                KoBookmark *endmark = bookmark->endBookmark();
-                Q_ASSERT(endmark);
-                if (endmark->position() > startPosition) {
-                    return QPair<int,int>(bookmark->position(), endmark->position());
-                }
-            }
-        }
-        // then check whether we've got a text:meta tag
-        else if (KoTextMeta *metamark = dynamic_cast<KoTextMeta*>(obj)) {
+        if (KoTextMeta *metamark = dynamic_cast<KoTextMeta*>(obj)) {
             if (metamark->type() == KoTextMeta::StartBookmark) {
                 KoTextMeta *endmark = metamark->endBookmark();
                 Q_ASSERT(endmark);
@@ -961,21 +959,34 @@ QPair<int, int> KoDocumentRdf::findExtent(KoTextEditor *handler) const
                                 cursor.position(),
                                 QTextDocument::FindBackward);
     }
+    */
     return QPair<int, int>(0, 0);
 }
 
 QString KoDocumentRdf::findXmlId(KoTextEditor *handler) const
 {
-
     int startPosition = handler->position();
-    KoInlineTextObjectManager *inlineObjectManager
-                = KoTextDocument(handler->document()).inlineTextObjectManager();
-    Q_ASSERT(inlineObjectManager);
 
     KoTextInlineRdf *inlineRdf = 0;
 
-    // find the bookmark-start or text:meta inline objects
     const QTextDocument *document = handler->document();
+
+    // first check for bookmarks
+    KoTextRangeManager *mgr = KoTextDocument(document).textRangeManager();
+    Q_ASSERT(mgr);
+    QHash<int, KoTextRange *> textRanges = mgr->textRangesChangingWithin(0, handler->selectionEnd(), handler->selectionStart(), -1);
+    foreach (const KoTextRange *range, textRanges) {
+        inlineRdf = range->inlineRdf();
+        if (inlineRdf) {
+            return inlineRdf->xmlId();
+        }
+    }
+
+/*
+    // find the text:meta inline objects
+    KoInlineTextObjectManager *inlineObjectManager
+                = KoTextDocument(document).inlineTextObjectManager();
+    Q_ASSERT(inlineObjectManager);
     QTextCursor cursor = document->find(QString(QChar::ObjectReplacementCharacter),
                                         startPosition,
                                         QTextDocument::FindBackward);
@@ -985,21 +996,7 @@ QString KoDocumentRdf::findXmlId(KoTextEditor *handler) const
         KoInlineObject *obj = inlineObjectManager->inlineTextObject(fmt);
         RDEBUG << "obj" << obj;
 
-        // first check for bookmarks
-        if (KoBookmark *bookmark = dynamic_cast<KoBookmark*>(obj)) {
-            KoBookmark::BookmarkType type = bookmark->type();
-            if (type == KoBookmark::StartBookmark) {
-                KoBookmark *endmark = bookmark->endBookmark();
-                // we used to assert on endmark, but we cannot keep people from
-                // inserting a startbookmark and only then creating and inserting
-                // the endmark
-                if (endmark && endmark->position() > startPosition) {
-                    inlineRdf = bookmark->inlineRdf();
-                }
-            }
-        }
-        // then check whether we've got a text:meta tag
-        else if (KoTextMeta *metamark = dynamic_cast<KoTextMeta*>(obj)) {
+        if (KoTextMeta *metamark = dynamic_cast<KoTextMeta*>(obj)) {
             if (metamark->type() == KoTextMeta::StartBookmark) {
                 KoTextMeta *endmark = metamark->endBookmark();
                 // we used to assert on endmark, but we cannot keep people from
@@ -1010,10 +1007,6 @@ QString KoDocumentRdf::findXmlId(KoTextEditor *handler) const
                 }
             }
         }
-        else if (obj){
-            // maybe we got another inline object that has rdf...
-            inlineRdf = obj->inlineRdf();
-        }
 
         // if we've got inline rdf, we've found the nearest xmlid wrapping our current position
         if (inlineRdf) {
@@ -1028,7 +1021,7 @@ QString KoDocumentRdf::findXmlId(KoTextEditor *handler) const
                                 cursor.position()-1,
                                 QTextDocument::FindBackward);
     }
-
+*/
     // we couldn't find inline rdf object... So try to see whether there's
     // inlineRdf in the charformat for the current cursor position. It's
     // unlikely, of course. Maybe this should be the first check, though?
