@@ -39,6 +39,10 @@
 
 #include "KoView.h"
 
+#include <KPageDialog>
+
+class KoPageLayoutWidget;
+
 class QModelIndex;
 
 class KAction;
@@ -483,12 +487,27 @@ private:
     QTimer m_autoScrollTimer;
 };
 
+//--------------------
+class DependencyeditorConfigDialog : public KPageDialog {
+    Q_OBJECT
+public:
+    DependencyeditorConfigDialog( ViewBase *view, QWidget *parent );
+
+public slots:
+    void slotOk();
+
+private:
+    ViewBase *m_view;
+    KoPageLayoutWidget *m_pagelayout;
+    PrintingHeaderFooter *m_headerfooter;
+};
+
 //------------------------------
 class KPLATOUI_EXPORT DependencyEditor : public ViewBase
 {
     Q_OBJECT
 public:
-    DependencyEditor( KoDocument *part, QWidget *parent );
+    DependencyEditor(KoPart *part, KoDocument *doc, QWidget *parent);
     
     void setupGui();
     Project *project() const { return m_view->project(); }
@@ -527,6 +546,9 @@ public slots:
     void slotCreateRelation( DependencyConnectorItem *pred, DependencyConnectorItem *succ );
     void setScheduleManager( ScheduleManager *sm );
 
+protected slots:
+    virtual void slotOptions();
+
 protected:
     void updateActionsEnabled( bool on );
     int selectedNodeCount() const;
