@@ -23,13 +23,19 @@
 #include "kptdebug.h"
 
 #include <kaction.h>
-#include <kicon.h>
 #include <kparts/event.h>
 #include <kxmlguifactory.h>
 #include <kmessagebox.h>
+#include <knotification.h>
+#include <kactioncollection.h>
+#include <kactionmenu.h>
+#include <kmenu.h>
 
+#include <KoIcon.h>
 #include "calligraversion.h"
 #include <KoDocument.h>
+#include <KoPart.h>
+#include <KoMainWindow.h>
 #include <KoShape.h>
 #include <KoPageLayoutWidget.h>
 #include <KoPagePreviewWidget.h>
@@ -46,11 +52,88 @@
 #include <QStyleOption>
 #include <QPainter>
 #include <QMenu>
-
+#include <QPainter>
 
 namespace KPlato
 {
 
+DockWidget::DockWidget( ViewBase *v, const QString &identity,  const QString &title )
+    : QDockWidget( v ),
+    view( v ),
+    id( identity ),
+    location( Qt::RightDockWidgetArea ),
+    editor( false ),
+    m_shown( true )
+{
+    setWindowTitle( title );
+    setObjectName( v->objectName() + '-' + identity );
+    toggleViewAction()->setObjectName( objectName() );
+    connect(this, SIGNAL(dockLocationChanged(Qt::DockWidgetArea)), SLOT(setLocation(Qt::DockWidgetArea)));
+}
+
+void DockWidget::activate( KoMainWindow *shell )
+{
+    connect(this, SIGNAL(visibilityChanged(bool)), this, SLOT(setShown(bool)));
+    setVisible( m_shown );
+    shell->addDockWidget( location, this );
+
+    foreach(const KActionCollection *c, KActionCollection::allCollections()) {
+        KActionMenu *a = qobject_cast<KActionMenu*>(c->action("settings_dockers_menu"));
+        if ( a ) {
+            a->addAction( toggleViewAction() );
+            break;
+        }
+    }
+}
+
+void DockWidget::deactivate( KoMainWindow *shell )
+{
+    disconnect(this, SIGNAL(visibilityChanged(bool)), this, SLOT(setShown(bool)));
+    shell->removeDockWidget( this );
+    foreach(const KActionCollection *c, KActionCollection::allCollections()) {
+        KActionMenu *a = qobject_cast<KActionMenu*>(c->action("settings_dockers_menu"));
+        if ( a ) {
+            a->removeAction( toggleViewAction() );
+            break;
+        }
+    }
+}
+
+void DockWidget::setShown( bool show )
+{
+    m_shown = show;
+    setVisible( show );
+}
+
+bool KPlato::DockWidget::shown() const
+{
+    return m_shown;
+}
+
+void DockWidget::setLocation( Qt::DockWidgetArea area )
+{
+    location = area;
+}
+
+bool DockWidget::saveXml( QDomElement &context ) const
+{
+    QDomElement e = context.ownerDocument().createElement( "docker" );
+    context.appendChild( e );
+    e.setAttribute( "id", id );
+    e.setAttribute( "location", location );
+    e.setAttribute( "floating", isFloating() );
+    e.setAttribute( "visible", m_shown );
+    return true;
+}
+
+void DockWidget::loadXml(const KoXmlElement& context)
+{
+    location = static_cast<Qt::DockWidgetArea>( context.attribute( "location", "0" ).toInt() );
+    setFloating( (bool) context.attribute( "floating", "0" ).toInt() );
+    m_shown = context.attribute( "visible", "1" ).toInt();
+}
+
+//------------------------
 bool PrintingOptions::loadXml( KoXmlElement &element )
 {
     KoXmlElement e;
@@ -122,6 +205,7 @@ PrintingHeaderFooter::~PrintingHeaderFooter()
 
 void PrintingHeaderFooter::slotChanged()
 {
+    kDebug(planDbg());
     emit changed( options() );
 }
 
@@ -165,7 +249,14 @@ PrintingDialog::PrintingDialog( ViewBase *view )
     m_view( view ),
     m_widget( 0 )
 {
-    setPrinterPageLayout();
+    setPrinterPageLayout( view->pageLayout() );
+    QImage px( 100, 600, QImage::Format_Mono );
+    int dpm = printer().resolution() * 40;
+    px.setDotsPerMeterX( dpm );
+    px.setDotsPerMeterY( dpm );
+    QPainter p( &px );
+    m_textheight = p.boundingRect( QRectF(), Qt::AlignTop, "Aj" ).height();
+    kDebug(planDbg())<<"textheight:"<<m_textheight;
 }
 
 PrintingDialog::~PrintingDialog()
@@ -187,62 +278,47 @@ PrintingOptions PrintingDialog::printingOptions() const
 
 void PrintingDialog::setPrintingOptions( const PrintingOptions &opt )
 {
-    return m_view->setPrintingOptions( opt );
+    kDebug(planDbg());
+    m_view->setPrintingOptions( opt );
+    emit changed( opt );
+    emit changed();
 }
 
-void PrintingDialog::setPrinterPageLayout()
+void PrintingDialog::setPrinterPageLayout( const KoPageLayout &pagelayout )
 {
     QPrinter &p = printer();
-    KoPageLayout l = m_view->pageLayout();
     QPrinter::Orientation o;
-    switch ( l.orientation ) {
+    switch ( pagelayout.orientation ) {
         case KoPageFormat::Portrait: o = QPrinter::Portrait; break;
         case KoPageFormat::Landscape: o = QPrinter::Landscape; break;
         default: o = QPrinter::Portrait; break;
     }
     p.setOrientation( o );
-    p.setPaperSize( KoPageFormat::printerPageSize( l.format ) );
-    p.setPageMargins( l.leftMargin, l.topMargin, l.rightMargin, l.bottomMargin, QPrinter::Point );
+    p.setPaperSize( KoPageFormat::printerPageSize( pagelayout.format ) );
+    p.setPageMargins( pagelayout.leftMargin, pagelayout.topMargin, pagelayout.rightMargin, pagelayout.bottomMargin, QPrinter::Point );
 }
 
 void PrintingDialog::startPrinting(RemovePolicy removePolicy )
 {
-    // FIXME: this triggers a crash in QPrintPreviewDialog if printing options != default
-    PrintingOptions opt;
-    if ( m_widget ) {
-        opt = m_widget->options();
-    }
-    setPrintingOptions( opt );
+    setPrinterPageLayout( m_view->pageLayout() ); // FIXME: Something resets printer().paperSize() to A4 !
     KoPrintingDialog::startPrinting( removePolicy );
 }
 
 QWidget *PrintingDialog::createPageLayoutWidget() const
 {
-    QWidget *widget = new QWidget();
-    widget->setWindowTitle( i18nc( "@title:tab", "Page Layout" ) );
-
-    QHBoxLayout *lay = new QHBoxLayout(widget);
-
-    KoPageLayoutWidget *w = new KoPageLayoutWidget( widget, m_view->pageLayout() );
-    w->showPageSpread( false );
-    lay->addWidget( w, 1 );
-
-    KoPagePreviewWidget *prev = new KoPagePreviewWidget( widget );
-    prev->setPageLayout( m_view->pageLayout() );
-    lay->addWidget( prev, 1 );
-
-    connect(w, SIGNAL(layoutChanged(const KoPageLayout&)), m_view, SLOT(setPageLayout(const KoPageLayout&)));
-
-    connect (w, SIGNAL(layoutChanged(const KoPageLayout&)), prev, SLOT(setPageLayout(const KoPageLayout&)));
-
-    return widget;
+    QWidget *w = ViewBase::createPageLayoutWidget( m_view );
+    KoPageLayoutWidget *pw = w->findChild<KoPageLayoutWidget*>();
+    connect(pw, SIGNAL(layoutChanged(const KoPageLayout&)), m_view, SLOT(setPageLayout(const KoPageLayout&)));
+    connect(pw, SIGNAL(layoutChanged(const KoPageLayout&)), this, SLOT(setPrinterPageLayout(const KoPageLayout&)));
+    connect(pw, SIGNAL(layoutChanged(const KoPageLayout&)), this, SIGNAL(changed()));
+    return w;
 }
 
 QList<QWidget*> PrintingDialog::createOptionWidgets() const
 {
     //kDebug(planDbg());
     PrintingHeaderFooter *w = new PrintingHeaderFooter( printingOptions() );
-    connect(w, SIGNAL(changed(const PrintingOptions&)), m_view, SLOT(setPrintingOptions(const PrintingOptions&)));
+    connect(w, SIGNAL(changed(PrintingOptions)), this, SLOT(setPrintingOptions(const PrintingOptions&)));
     const_cast<PrintingDialog*>( this )->m_widget = w;
 
     return QList<QWidget*>() << w;
@@ -283,14 +359,14 @@ QRect PrintingDialog::footerRect() const
 
 int PrintingDialog::headerFooterHeight( const PrintingOptions::Data &options ) const
 {
-    int height = 0;
+    int height = 0.0;
     if ( options.page == Qt::Checked || options.project == Qt::Checked || options.manager == Qt::Checked || options.date == Qt::Checked ) {
-        height += painter().boundingRect( const_cast<PrintingDialog*>( this )->printer().pageRect(), Qt::AlignTop, "Aj" ).height();
-        height *= 1.5;
+        height += m_textheight * 1.5;
     }
     if (  options.project == Qt::Checked && options.manager == Qt::Checked && ( options.date == Qt::Checked || options.page == Qt::Checked ) ) {
-        height *= 2.0;
+       height *= 2.0;
     }
+    kDebug(planDbg())<<height;
     return height;
 }
 
@@ -410,8 +486,8 @@ void PrintingDialog::paint( QPainter &p, const PrintingOptions::Data &options, c
 }
 
 //--------------
-ViewBase::ViewBase(KoDocument *doc, QWidget *parent)
-    : KoView( doc, parent ),
+ViewBase::ViewBase(KoPart *part, KoDocument *doc, QWidget *parent)
+    : KoView(part, doc, parent),
     m_readWrite( false ),
     m_proj( 0 ),
     m_schedulemanager( 0 )
@@ -426,6 +502,12 @@ ViewBase::~ViewBase()
     }
 }
 
+void ViewBase::setProject( Project *project )
+{
+    m_proj = project;
+    emit projectChanged( project );
+}
+
 KoDocument *ViewBase::part() const
 {
      return koDocument();
@@ -457,6 +539,7 @@ bool ViewBase::isActive() const
 void ViewBase::updateReadWrite( bool readwrite )
 {
     m_readWrite = readwrite;
+    emit readWriteChanged( readwrite );
 }
 
 void ViewBase::setGuiActive( bool active ) // virtual slot
@@ -477,6 +560,37 @@ KoPrintJob *ViewBase::createPrintJob()
     return 0;
 }
 
+/*static*/
+QWidget *ViewBase::createPageLayoutWidget( ViewBase *view )
+{
+    QWidget *widget = new QWidget();
+    widget->setWindowTitle( i18nc( "@title:tab", "Page Layout" ) );
+
+    QHBoxLayout *lay = new QHBoxLayout(widget);
+
+    KoPageLayoutWidget *w = new KoPageLayoutWidget( widget, view->pageLayout() );
+    w->showPageSpread( false );
+    lay->addWidget( w, 1 );
+
+    KoPagePreviewWidget *prev = new KoPagePreviewWidget( widget );
+    prev->setPageLayout( view->pageLayout() );
+    lay->addWidget( prev, 1 );
+
+    connect (w, SIGNAL(layoutChanged(const KoPageLayout&)), prev, SLOT(setPageLayout(const KoPageLayout&)));
+
+    return widget;
+}
+
+/*static*/
+PrintingHeaderFooter *ViewBase::createHeaderFooterWidget( ViewBase *view )
+{
+    PrintingHeaderFooter *widget = new PrintingHeaderFooter( view->printingOptions() );
+    widget->setWindowTitle( i18nc( "@title:tab", "Header and Footer" ) );
+    widget->setOptions( view->printingOptions() );
+
+    return widget;
+}
+
 void ViewBase::slotHeaderContextMenuRequested( const QPoint &pos )
 {
     kDebug(planDbg());
@@ -488,7 +602,7 @@ void ViewBase::slotHeaderContextMenuRequested( const QPoint &pos )
 
 void ViewBase::createOptionAction()
 {
-    actionOptions = new KAction(KIcon("configure"), i18n("Configure View..."), this);
+    actionOptions = new KAction(koIcon("configure"), i18n("Configure View..."), this);
     connect(actionOptions, SIGNAL(triggered(bool) ), SLOT(slotOptions()));
     addContextAction( actionOptions );
 }
@@ -518,6 +632,14 @@ bool ViewBase::loadContext( const KoXmlElement &context )
             m_pagelayout.bottomMargin = me.attribute( "bottom-margin", QString::number( MM_TO_POINT( 20.0 ) ) ).toDouble();
         } else if ( me.tagName() == "printing-options" ) {
             m_printingOptions.loadXml( me );
+        } else if ( me.tagName() == "dockers" ) {
+            KoXmlElement e;
+            forEachElement ( e, me ) {
+                DockWidget *ds = findDocker( e.attribute( "id" ) );
+                if ( ds ) {
+                    ds->loadXml( e );
+                }
+            }
         }
     }
     return true;
@@ -537,6 +659,35 @@ void ViewBase::saveContext( QDomElement &context ) const
     me.setAttribute( "bottom-margin", m_pagelayout.bottomMargin );
 
     m_printingOptions.saveXml( context );
+
+    if ( ! m_dockers.isEmpty() ) {
+        QDomElement e = context.ownerDocument().createElement( "dockers" );
+        context.appendChild( e );
+        foreach ( const DockWidget *ds, m_dockers ) {
+            ds->saveXml( e );
+        }
+    }
+}
+
+void ViewBase::addDocker( DockWidget *ds )
+{
+    //addAction( "view_docker_list", ds->toggleViewAction() );
+    m_dockers << ds;
+}
+
+QList<DockWidget*> ViewBase::dockers() const
+{
+    return m_dockers;
+}
+
+DockWidget* ViewBase::findDocker( const QString &id ) const
+{
+    foreach ( DockWidget *ds, m_dockers ) {
+        if ( ds->id == id ) {
+            return ds;
+        }
+    }
+    return 0;
 }
 
 //----------------------
@@ -546,12 +697,15 @@ TreeViewPrintingDialog::TreeViewPrintingDialog( ViewBase *view, TreeViewBase *tr
     m_project( project ),
     m_firstRow( -1 )
 {
+    printer().setFromTo( documentFirstPage(), documentLastPage() );
 }
 
 int TreeViewPrintingDialog::documentLastPage() const
 {
     int page = documentFirstPage();
-    while ( firstRow( page ) != -1 ) { ++page; }
+    while ( firstRow( page ) != -1 ) {
+        ++page;
+    }
     if ( page > documentFirstPage() ) {
         --page;
     }
@@ -601,7 +755,7 @@ int TreeViewPrintingDialog::firstRow( int page ) const
             row = -1;
         }
     }
-    kDebug(planDbg())<<row<<rowsPrPage;
+    kDebug(planDbg())<<"Page"<<page<<":"<<(row==-1?"empty":"first row=")<<row<<"("<<rowsPrPage<<")";
     return row;
 }
 
@@ -615,8 +769,6 @@ QList<QWidget*> TreeViewPrintingDialog::createOptionWidgets() const
 
 void TreeViewPrintingDialog::printPage( int page, QPainter &painter )
 {
-    painter.save();
-
     m_firstRow = firstRow( page );
 
     QHeaderView *mh = m_tree->header();
@@ -675,7 +827,6 @@ void TreeViewPrintingDialog::printPage( int page, QPainter &painter )
     }
     if ( m_firstRow == -1 ) {
         kDebug(planDbg())<<"No data";
-        painter.restore();
         return;
     }
     painter.setBrush( QBrush() );
@@ -700,7 +851,6 @@ void TreeViewPrintingDialog::printPage( int page, QPainter &painter )
         ++numRows;
         idx = m_tree->indexBelow( idx );
     }
-    painter.restore();
 }
 
 /**
@@ -717,6 +867,7 @@ TreeViewBase::TreeViewBase( QWidget *parent )
     m_readWrite( false )
 
 {
+    setDefaultDropAction( Qt::MoveAction );
     setItemDelegate( new ItemDelegate( this ) );
     setAlternatingRowColors ( true );
 
@@ -725,6 +876,12 @@ TreeViewBase::TreeViewBase( QWidget *parent )
     connect( header(), SIGNAL( customContextMenuRequested( const QPoint& ) ), this, SLOT( slotHeaderContextMenuRequested( const QPoint& ) ) );
 }
 
+void TreeViewBase::dropEvent( QDropEvent *e )
+{
+    kDebug(planDbg());
+    QTreeView::dropEvent( e );
+}
+
 KoPrintJob * TreeViewBase::createPrintJob( ViewBase *parent )
 {
     TreeViewPrintingDialog *dia = new TreeViewPrintingDialog( parent, this, parent->project() );
@@ -1237,17 +1394,24 @@ void TreeViewBase::dragMoveEvent(QDragMoveEvent *event)
         if ( ! m_acceptDropsOnView ) {
             event->ignore();
         }
-        //kDebug(planDbg())<<"On viewport:"<<event->isAccepted();
-        return;
+        kDebug(planDbg())<<"On viewport:"<<event->isAccepted();
+    } else {
+        QModelIndex index = indexAt( event->pos() );
+        if ( index.isValid() ) {
+            emit dropAllowed( index, dropIndicatorPosition(), event );
+        } else {
+            event->ignore();
+            kDebug(planDbg())<<"Invalid index:"<<event->isAccepted();
+        }
     }
-    QModelIndex index = indexAt( event->pos() );
-    if ( ! index.isValid() ) {
-        event->ignore();
-        //kDebug(planDbg())<<"Invalid index:"<<event->isAccepted();
-        return;
+    if ( event->isAccepted() ) {
+        if ( viewport()->cursor().shape() == Qt::ForbiddenCursor ) {
+            viewport()->unsetCursor();
+        }
+    } else if ( viewport()->cursor().shape() != Qt::ForbiddenCursor ) {
+        viewport()->setCursor( Qt::ForbiddenCursor );
     }
-    emit dropAllowed( index, dropIndicatorPosition(), event );
-    //kDebug(planDbg())<<event->isAccepted();
+    kDebug(planDbg())<<event->isAccepted()<<viewport()->cursor().shape();
 }
 
 QModelIndex TreeViewBase::firstVisibleIndex( const QModelIndex &idx ) const
@@ -1384,12 +1548,16 @@ DoubleTreeViewPrintingDialog::DoubleTreeViewPrintingDialog( ViewBase *view, Doub
     m_project( project ),
     m_firstRow( -1 )
 {
+    printer().setFromTo( documentFirstPage(), documentLastPage() );
 }
 
 int DoubleTreeViewPrintingDialog::documentLastPage() const
 {
+    kDebug(planDbg())<<KoPageFormat::formatString( m_view->pageLayout().format );
     int page = documentFirstPage();
-    while ( firstRow( page ) != -1 ) { ++page; }
+    while ( firstRow( page ) != -1 ) {
+        ++page;
+    }
     if ( page > documentFirstPage() ) {
         --page;
     }
@@ -1417,6 +1585,9 @@ int DoubleTreeViewPrintingDialog::firstRow( int page ) const
     }
     int rowsPrPage = pageHeight / height;
 
+    kDebug(planDbg())<<"rowsPrPage"<<rowsPrPage;
+    Q_ASSERT( rowsPrPage > 0 );
+
     int rows = m_tree->model()->rowCount();
     int row = -1;
     for ( int i = 0; i < rows; ++i ) {
@@ -1440,7 +1611,7 @@ int DoubleTreeViewPrintingDialog::firstRow( int page ) const
             row = -1;
         }
     }
-    kDebug(planDbg())<<row<<rowsPrPage;
+    kDebug(planDbg())<<"Page"<<page<<":"<<(row==-1?"empty":"first row=")<<row<<"("<<rowsPrPage<<")";
     return row;
 }
 
@@ -1454,6 +1625,10 @@ QList<QWidget*> DoubleTreeViewPrintingDialog::createOptionWidgets() const
 
 void DoubleTreeViewPrintingDialog::printPage( int page, QPainter &painter )
 {
+    kDebug(planDbg())<<page<<"paper size:"<<printer().paperSize()<<"---------------------------";
+    setPrinterPageLayout( m_view->pageLayout() );
+    qreal t, l, b, r; printer().getPageMargins( &l, &t, &r, &b, QPrinter::Point );
+    kDebug(planDbg())<<page<<"paper size:"<<printer().paperSize()<<printer().pageRect()<<l<<t<<r<<b;
     painter.save();
 
     m_firstRow = firstRow( page );
@@ -1516,16 +1691,21 @@ void DoubleTreeViewPrintingDialog::printPage( int page, QPainter &painter )
         }
         //kDebug(planDbg())<<text<<"hidden="<<h->isSectionHidden( i )<<h->sectionPosition( i );
     }
-    if ( m_firstRow == -1 ) {
+    if ( m_firstRow == -1 || model->rowCount() == 0 ) {
         kDebug(planDbg())<<"No data";
         painter.restore();
         return;
     }
     painter.setBrush( QBrush() );
-    QModelIndex idx = model->index( m_firstRow, 0, QModelIndex() );
+
+    QModelIndex idx = model->index( 0, 0 );
+    for ( int r = 0; r < m_firstRow && idx.isValid(); ++r ) {
+        idx = m_tree->masterView()->indexBelow( idx );
+    }
     int numRows = 0;
     //kDebug(planDbg())<<page<<rowsPrPage;
     while ( idx.isValid() && numRows < rowsPrPage ) {
+        kDebug(planDbg())<<"print:"<<idx;
         painter.translate( 0, height );
         h += height;
         for ( int i = 0; i < mh->count(); ++i ) {
@@ -1651,7 +1831,7 @@ void DoubleTreeViewBase::init()
     connect( m_leftview, SIGNAL( dropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ), this, SIGNAL( dropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ) );
     connect( m_rightview, SIGNAL( dropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ), this, SIGNAL( dropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ) );
 
-    m_actionSplitView = new KAction(KIcon("view-split-left-right"), "", this);
+    m_actionSplitView = new KAction(koIcon("view-split-left-right"), QString(), this);
     setViewSplitMode( true );
 
     connect( m_leftview->header(), SIGNAL( sortIndicatorChanged( int, Qt::SortOrder ) ), SLOT( slotLeftSortIndicatorChanged( int, Qt::SortOrder ) ) );
@@ -1887,31 +2067,43 @@ void DoubleTreeViewBase::edit( const QModelIndex &index )
 void DoubleTreeViewBase::setDragDropMode( QAbstractItemView::DragDropMode mode )
 {
     m_leftview->setDragDropMode( mode );
+    m_rightview->setDragDropMode( mode );
+}
+
+void DoubleTreeViewBase::setDragDropOverwriteMode( bool mode )
+{
+    m_leftview->setDragDropOverwriteMode( mode );
+    m_rightview->setDragDropOverwriteMode( mode );
 }
 
 void DoubleTreeViewBase::setDropIndicatorShown( bool mode )
 {
     m_leftview->setDropIndicatorShown( mode );
+    m_rightview->setDropIndicatorShown( mode );
 }
 
 void DoubleTreeViewBase::setDragEnabled ( bool mode )
 {
     m_leftview->setDragEnabled( mode );
+    m_rightview->setDragEnabled( mode );
 }
 
 void DoubleTreeViewBase::setAcceptDrops( bool mode )
 {
     m_leftview->setAcceptDrops( mode );
+    m_rightview->setAcceptDrops( mode );
 }
 
 void DoubleTreeViewBase::setAcceptDropsOnView( bool mode )
 {
     m_leftview->setAcceptDropsOnView( mode );
+    m_rightview->setAcceptDropsOnView( mode );
 }
 
 void DoubleTreeViewBase::setDefaultDropAction( Qt::DropAction action )
 {
     m_leftview->setDefaultDropAction( action );
+    m_rightview->setDefaultDropAction( action );
 }
 
 void DoubleTreeViewBase::slotRightHeaderContextMenuRequested( const QPoint &pos )
@@ -1975,10 +2167,10 @@ void DoubleTreeViewBase::setViewSplitMode( bool split )
 {
     if ( split ) {
         m_actionSplitView->setText( i18n( "Unsplit View" ) );
-        m_actionSplitView->setIcon( KIcon( "view-close" ) );
+        m_actionSplitView->setIcon(koIcon("view-close"));
     } else {
         m_actionSplitView->setText( i18n( "Split View" ) );
-        m_actionSplitView->setIcon( KIcon( "view-split-left-right" ) );
+        m_actionSplitView->setIcon(koIcon("view-split-left-right"));
     }
 
     if ( m_mode == split ) {
