@@ -34,6 +34,7 @@
 #include <KoTextBlockData.h>
 #include <KoParagraphStyle.h>
 #include <KoInlineTextObjectManager.h>
+#include <KoTextRangeManager.h>
 #include <KoTextDocumentLayout.h>
 #include <KoZoomHandler.h>
 #include <KoStyleManager.h>
@@ -120,7 +121,8 @@ void SimpleParagraphWidget::fillListButtons()
     zoomHandler.setDpi(72, 72);
 
     KoInlineTextObjectManager itom;
-    TextShape textShape(&itom);
+    KoTextRangeManager tlm;
+    TextShape textShape(&itom, &tlm);
     textShape.setSize(QSizeF(300, 100));
     QTextCursor cursor (textShape.textShapeData()->document());
     foreach(Lists::ListStyleItem item, Lists::genericListStyleItems()) {
