@@ -67,6 +67,8 @@
 #include <KoZoomAction.h>
 #include <KoToolManager.h>
 #include <KoMainWindow.h>
+#include <KoTextRangeManager.h>
+#include <KoAnnotationManager.h>
 #include <KoTextEditor.h>
 #include <KoToolProxy.h>
 #include <KoTextAnchor.h>
@@ -81,6 +83,9 @@
 #include <rdf/KoDocumentRdf.h>
 #include <rdf/KoSemanticStylesheetsEditor.h>
 #endif
+
+#include <KoAnnotationSideBar.h>
+
 #include <KoFindStyle.h>
 #include <KoFindText.h>
 #include <KoFindToolbar.h>
@@ -114,9 +119,15 @@ KWView::KWView(KoPart *part, KWDocument *document, QWidget *parent)
     m_canvas = m_gui->canvas();
     setFocusProxy(m_canvas);
 
+#ifdef SHOW_ANNOTATIONS
+    QGridLayout *layout = new QGridLayout(this);
+    layout->setMargin(0);
+    layout->addWidget(m_gui,0,0);
+#else
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
     layout->addWidget(m_gui);
+#endif
 
     setComponentData(KWFactory::componentData());
     setXMLFile("words.rc");
@@ -165,6 +176,15 @@ KWView::KWView(KoPart *part, KWDocument *document, QWidget *parent)
         connect(actionCollection()->action("settings_active_author"), SIGNAL(triggered(const QString &)),
            m_document->inlineTextObjectManager(), SLOT(activeAuthorUpdated(const QString &)));
     }
+
+#ifdef SHOW_ANNOTATIONS
+    if (KoTextRangeManager *textRangeManager = m_document->textRangeManager()) {
+        if (textRangeManager->annotationManager()) {
+            KoAnnotationSideBar *annotationBar = new KoAnnotationSideBar(textRangeManager->annotationManager());
+            layout->addWidget(annotationBar, 0, 1);
+        }
+    }
+#endif
 }
 
 KWView::~KWView()
@@ -491,7 +511,7 @@ void KWView::addBookmark()
     KoTextEditor *editor = KoTextEditor::getTextEditorFromCanvas(canvasBase());
     Q_ASSERT(editor);
 
-    KoBookmarkManager *manager = m_document->inlineTextObjectManager()->bookmarkManager();
+    const KoBookmarkManager *manager = m_document->textRangeManager()->bookmarkManager();
     if (editor->hasSelection()) {
         suggestedName = editor->selectedText();
     }
@@ -512,7 +532,7 @@ void KWView::addBookmark()
 void KWView::selectBookmark()
 {
     QString name;
-    KoBookmarkManager *manager = m_document->inlineTextObjectManager()->bookmarkManager();
+    const KoBookmarkManager *manager = m_document->textRangeManager()->bookmarkManager();
 
     QPointer<KWSelectBookmarkDialog> dia = new KWSelectBookmarkDialog(manager->bookmarkNameList(), m_canvas->canvasWidget());
     connect(dia, SIGNAL(nameChanged(const QString &, const QString &)),
@@ -526,8 +546,8 @@ void KWView::selectBookmark()
         return;
     }
     delete dia;
+    KoBookmark *bookmark = manager->bookmark(name);
 #if 0
-    KoBookmark *bookmark = manager->retrieveBookmark(name);
     KoShape *shape = bookmark->shape();
     KoSelection *selection = canvasBase()->shapeManager()->selection();
     selection->deselectAll();
@@ -535,20 +555,24 @@ void KWView::selectBookmark()
 
     QString tool = KoToolManager::instance()->preferredToolForSelection(selection->selectedShapes());
     KoToolManager::instance()->switchToolRequested(tool);
-
-    KoCanvasResourceManager *rm = m_canvas->resourceManager();
-    if (bookmark->hasSelection()) {
-        rm->setResource(KoText::CurrentTextPosition, bookmark->position());
-        rm->setResource(KoText::CurrentTextAnchor, bookmark->endBookmark()->position() + 1);
-        rm->clearResource(KoText::SelectedTextPosition);
-        rm->clearResource(KoText::SelectedTextAnchor);
-    } else
-        rm->setResource(KoText::CurrentTextPosition, bookmark->position() + 1);
 #else
 #ifdef __GNUC__
     #warning FIXME: port to textlayout-rework
 #endif
 #endif
+
+    KoCanvasResourceManager *rm = m_canvas->resourceManager();
+    if ((bookmark->positionOnlyMode() == false) && bookmark->hasRange()) {
+        rm->clearResource(KoText::SelectedTextPosition);
+        rm->clearResource(KoText::SelectedTextAnchor);
+    }
+    if (bookmark->positionOnlyMode()) {
+        rm->setResource(KoText::CurrentTextPosition, bookmark->rangeStart());
+        rm->setResource(KoText::CurrentTextAnchor, bookmark->rangeStart());
+    } else {
+        rm->setResource(KoText::CurrentTextPosition, bookmark->rangeStart());
+        rm->setResource(KoText::CurrentTextAnchor, bookmark->rangeEnd());
+    }
 }
 
 void KWView::deleteBookmark(const QString &name)
@@ -556,7 +580,7 @@ void KWView::deleteBookmark(const QString &name)
     Q_UNUSED(name);
 #if 0
     KoInlineTextObjectManager*manager = m_document->inlineTextObjectManager();
-    KoBookmark *bookmark = manager->bookmarkManager()->retrieveBookmark(name);
+    KoBookmark *bookmark = manager->bookmarkManager()->bookmark(name);
     if (!bookmark || !bookmark->shape())
         return;
 
